using System;
using System.Collections.Generic;
using System.Text;

namespace myMSP_ws_demo
{
    /// <summary>
    /// Handles all communications with the Web Service
    /// </summary>
    class WebServiceCommunication
    {
        // The web service connection-object
        private WebReference.MyMSP2 _webService = new WebReference.MyMSP2();

        // A utility class
        private Utilities _utilities = new Utilities();

        /// <summary>
        /// Pings the server
        /// </summary>
        /// <returns>A response that indicates if the server is accessible</returns>
        internal WebReference.pingResponse ping()
        {
            // Create and fill a ping object
            WebReference.ping aPing = new WebReference.ping();
            aPing.String_1 = "Are you alive?";

            // Create a response object that stores the result of the ping-attempt
            WebReference.pingResponse response;
            
            try
            {
                // Ping the server
                response = _webService.ping(aPing);
            }
            catch
            {
                response = null;
            }

            return response;
        }

        /// <summary>
        /// Gets a set of parameters from the myMSP
        /// </summary>
        /// <param name="userName">The user name</param>
        /// <param name="password">The password</param>
        /// <returns>A response containing sets of parameters</returns>
        internal WebReference.getParamsResponse getParameters(
            string userName,
            string password)
        {
            // Create and fill a identification object
            WebReference.Identification id = new WebReference.Identification();
            id.username = userName;
            id.pwd = password;
            id.clientType = "wsClient";
            id.clientVersion = "";

            // Create and fill a parameter request
            WebReference.BasicRequest request = new WebReference.BasicRequest();
            request.identification = id;

            // Create a getParams object that will contain all the data that should
            // be sent to the web service
            WebReference.getParams inParameters = new WebReference.getParams();

            // Add the parameter request to the getParams object
            inParameters.BasicRequest_1 = request;

            // Create a response variable that stores the result of the get parameters-attempt
            WebReference.getParamsResponse response = new WebReference.getParamsResponse();

            try
            {
                // Get the parameters
                response = _webService.getParams(inParameters);
            }
            catch
            {
                response = null;
            }

            // Return the response
            return response;
        }

        /// <summary>
        /// Sends a SMS-message to the web service
        /// </summary>
        /// <param name="userName">The user name</param>
        /// <param name="password">The password</param>
        /// <returns>A response containing the result of send attempt</returns>
        public WebReference.sendMsgResponse sendSMS(
            string userName,
            string password)
        {
            // Create and fill a identification object
            WebReference.Identification id = new WebReference.Identification();
            id.username = userName;
            id.pwd = password;
            id.clientType = "wsClient";
            id.clientVersion = "";

            // Create a recipient array
            WebReference.Recipient[] recipients = new WebReference.Recipient[1];

            // Create and fill a recipient object
            WebReference.Recipient recipient = new WebReference.Recipient();
            recipient.mobileNumber = "46709999999";
            recipient.recipientName = "Jane Doe";
            recipient.externalRef = "";

            // Add the recipient to the recipient array
            recipients[0] = recipient;

            // Create a send request object
            WebReference.SendRequest sendRequest = new WebReference.SendRequest();
            
            // Fill the send request
            sendRequest.identification = id;
            sendRequest.recipients = recipients;
            sendRequest.msgType = "SMS";
            sendRequest.smsText = "Hello, this is a test message.";
            sendRequest.requestReadReceipt = true;
            sendRequest.subject = "";
            sendRequest.originatorText = "";
            sendRequest.externalRef = "";
            sendRequest.contents = null;

            // Create a sendMsg object that will contain all the data that should
            // be sent to the web service
            WebReference.sendMsg sendSms = new WebReference.sendMsg();

            // Add the send request to the sendMsg-object
            sendSms.SendRequest_1 = sendRequest;

            // Create a response object that stores the result of the send-attempt
            WebReference.sendMsgResponse response = null;

            try
            {
                // Send the message
                response = _webService.sendMsg(sendSms);
            }
            catch
            {
                response = null;
            }

            // Return the response
            return response;
        }

        /// <summary>
        /// Sends a MMS-message to the web service
        /// </summary>
        /// <param name="userName">The user name</param>
        /// <param name="password">The password</param>
        /// <returns>A response containing the result of the send attempt</returns>
        public WebReference.sendMsgResponse sendMMS(
            string userName,
            string password)
        {
            // Create and fill a identification object
            WebReference.Identification id = new WebReference.Identification();
            id.username = userName;
            id.pwd = password;
            id.clientType = "wsClient";
            id.clientVersion = "";

            // Create a recipient array
            WebReference.Recipient[] recipients = new WebReference.Recipient[1];

            // Create and fill a recipient object
            WebReference.Recipient recipient = new WebReference.Recipient();
            recipient.mobileNumber = "46709999999";
            recipient.recipientName = "Jane Doe";
            recipient.externalRef = "";

            // Add the recipient to the recipient array
            recipients[0] = recipient;
            
            // Create a MMS-content array
            WebReference.MessageContent[] contents = new WebReference.MessageContent[1];

            // Create a MMS-content page
            WebReference.MessageContent page = new WebReference.MessageContent();
            page.contentBytes = _utilities.imageAsByteArray();
            page.contentCharset = "";
            page.contentType = "image/gif";
            page.slideNo = 1;
            
            // Add the page to the content array
            contents[0] = page;

            // Create a send request object
            WebReference.SendRequest sendRequest = new WebReference.SendRequest();

            // Fill the send request
            sendRequest.identification = id;
            sendRequest.recipients = recipients;
            sendRequest.msgType = "MMS";
            sendRequest.smsText = "Hello, this is a test message.";
            sendRequest.requestReadReceipt = true;
            sendRequest.subject = "Test MMS";
            sendRequest.originatorText = "";
            sendRequest.externalRef = "";
            sendRequest.contents = contents;

            // Create a sendMsg object that will contain all the data that should
            // be sent to the web service
            WebReference.sendMsg sendMms = new WebReference.sendMsg();

            // Add the send request to the sendMsg-object
            sendMms.SendRequest_1 = sendRequest;

            // Create a response object that stores the result of the send-attempt
            WebReference.sendMsgResponse response = null;

            try
            {
                // Send the message
                response = _webService.sendMsg(sendMms);
            }
            catch
            {
                response = null;
            }

            // Return the response
            return response;
        }

        /// <summary>
        /// Gets a send result for a message
        /// </summary>
        /// <param name="userName">The user name</param>
        /// <param name="password">The password</param>
        /// <returns>A response containing the send result of a message</returns>
        internal WebReference.getSendResultResponse getSendResult(
            string userName,
            string password)
        {
            // Create and fill a identification object
            WebReference.Identification id = new WebReference.Identification();
            id.username = userName;
            id.pwd = password;
            id.clientType = "wsClient";
            id.clientVersion = "";

            // Create and fill a send result request
            WebReference.SendResultRequest request = new WebReference.SendResultRequest();
            request.identification = id;
            request.msgNo = 1000; // Change the msgno to check the send status of different messages

            // Create a getSendResult object that will contain all the data that should
            // be sent to the web service
            WebReference.getSendResult sendResult = new WebReference.getSendResult();
            sendResult.SendResultRequest_1 = request;

            // Create a response object that stores the result of the get send result-attempt
            WebReference.getSendResultResponse response;

            try
            {
                // Send the request
                response = _webService.getSendResult(sendResult);
            }
            catch
            {
                response = null;
            }

            // Return the response
            return response;
        }

        /// <summary>
        /// Gets send results for several messages
        /// </summary>
        /// <param name="userName">The user name</param>
        /// <param name="password">The password</param>
        /// <returns>A response containing the send results of a batch of messages</returns>
        internal WebReference.getSendResultsResponse getSendResults(
            string userName,
            string password)
        {
            // Create and fill a identification object
            WebReference.Identification id = new WebReference.Identification();
            id.username = userName;
            id.pwd = password;
            id.clientType = "wsClient";
            id.clientVersion = "";

            // Create and fill a send results request
            WebReference.SendResultsRequest request = new WebReference.SendResultsRequest();
            request.identification = id;
            request.sinceTime = "20111026000101001"; // Change the msgno to check the send status of different messages

            // Create a getSendResults-object that will contain all the data that should
            // be sent to the web service
            WebReference.getSendResults sendResultsResult = new WebReference.getSendResults();
            sendResultsResult.SendResultsRequest_1 = request;

            // Create a response object that stores the result of the get send results-attempt
            WebReference.getSendResultsResponse response;

            try
            {
                // Send the request
                response = _webService.getSendResults(sendResultsResult);
            }
            catch
            {
                response = null;
            }

            // Return the response
            return response;
        }

        /// <summary>
        /// Gets received messages from the web service
        /// </summary>
        /// <param name="userName">The user name</param>
        /// <param name="password">The password</param>
        /// <returns>A response containing a set of received messages</returns>
        internal WebReference.getReceivedMessagesResponse getReceivedMessages(
            string userName,
            string password)
        {
            // Create and fill a identification object
            WebReference.Identification id = new WebReference.Identification();
            id.username = userName;
            id.pwd = password;
            id.clientType = "wsClient";
            id.clientVersion = "";

            // Create and fill a get received messages request
            WebReference.ReceivedMessRequest request = new WebReference.ReceivedMessRequest();
            request.identification = id;
            request.lastMsgNo = 0; //All received messages are collected if the value is zero

            // Create a getReceivedMessages object that will contain all the data that should
            // be sent to the web service
            WebReference.getReceivedMessages receivedMessages = new WebReference.getReceivedMessages();
            receivedMessages.ReceivedMessRequest_1 = request;

            // Create a response object that stores the result of the get received messages-attempt
            WebReference.getReceivedMessagesResponse response;

            try
            {
                response = _webService.getReceivedMessages(receivedMessages);
            }
            catch
            {
                response = null;
            }

            return response;
        }

        /// <summary>
        /// Gets the content of a MMS and displays it
        /// </summary>
        /// <param name="userName">The user name</param>
        /// <param name="password">The password</param>
        /// <returns>A response containing the content of an MMS</returns>
        internal WebReference.getMsgContentResponse getMmsContent(
            string userName,
            string password)
        {
            // Create and fill a identification object
            WebReference.Identification id = new WebReference.Identification();
            id.username = userName;
            id.pwd = password;
            id.clientType = "wsClient";
            id.clientVersion = "";

            // Create and fill a get message content request
            WebReference.MsgContentRequest request = new WebReference.MsgContentRequest();
            request.identification = id;
            request.msgNo = 1000; // Change this to get the content of another MMS
            
            // Create a getReceivedMessages object that will contain all the data that should
            // be sent to the web service
            WebReference.getMsgContent content = new WebReference.getMsgContent();
            content.MsgContentRequest_1 = request;

            // Create a response object that stores the result of the get message content-attempt
            WebReference.getMsgContentResponse response;

            try
            {
                response = _webService.getMsgContent(content);
            }
            catch
            {
                response = null;
            }

            return response;
        }
    }
}