using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace myMSP_ws_demo
{
    public partial class frmDemo : Form
    {
        // Create a new instance of the WebServiceCommunication-class
        private WebServiceCommunication webservice = new WebServiceCommunication();

        // A utility class
        private Utilities _utilities = new Utilities();

        public frmDemo()
        {
            InitializeComponent();
            txtUserName.Focus();
        }

        private void frmDemo_Load(object sender, EventArgs e)
        {
            txtUserName.Focus();
            txtUserName.SelectAll();
        }

        //
        // Buttons
        //
        #region Buttons

        private void cmbPing_Click(object sender, EventArgs e)
        {
            this.ping();
        }

        private void cmbGetParams_Click(object sender, EventArgs e)
        {
            this.getParameters();
        }

        private void cmbSendSMS_Click(object sender, EventArgs e)
        {
            this.sendSMS();
        }

        private void cmbSendMMS_Click(object sender, EventArgs e)
        {
            this.sendMMS();
        }

        private void cmbGetSendResult_Click(object sender, EventArgs e)
        {
            this.getSendResult();
        }

        private void cmbGetSendResults_Click(object sender, EventArgs e)
        {
            this.getSendResults();
        }

        private void cmbGetReceivedMessages_Click(object sender, EventArgs e)
        {
            this.getReceivedMessages();
        }

        private void cmbGetAReceivedMms_Click(object sender, EventArgs e)
        {
            this.getAReceivedMms();
        }

        #endregion

        /// <summary>
        /// Ping the server
        /// </summary>
        private void ping()
        {
            // Create a variable that will receive the ping response
            WebReference.pingResponse response;

            // Ping the server
            response = webservice.ping();

            // Read and display the response
            if (response != null)
            {
                MessageBox.Show("Ping OK!");
            }
            else
            {
                MessageBox.Show("An error occured");
            }
        }

        /// <summary>
        /// Gets a set of parameters
        /// </summary>
        private void getParameters()
        {
            // Create a variable that will receive the parameters
            WebReference.getParamsResponse response;

            // Get parameters
            response = webservice.getParameters(
                txtUserName.Text,
                txtPassword.Text);

            // Read and display the parameter response
            if (response != null)
            {
                string resultCode = response.result.resultCode.ToString();
                string resultDescription = response.result.resultDescription;
                WebReference.Param[] systemParameters = response.result.clientParams;
                WebReference.Param[] userParameters = response.result.userParams;
                string[] initalIds = response.result.initialIds;
                string[] originatorTexts = response.result.originatorTexts;

                string resultString = "";
                string systemParametersString = "";
                string userParametersString = "";
                string initialIdsString = "";
                string originatorTextsString = "";

                // Gather results
                resultString =
                    "Result code: " + resultCode + Environment.NewLine + Environment.NewLine +
                    "Result description: " + resultDescription;

                // Gather system parameters
                if (systemParameters != null)
                {
                    foreach (WebReference.Param aSystemParameter in systemParameters)
                    {
                        if (aSystemParameter != null)
                        {
                            systemParametersString =
                                systemParametersString +
                                "  Key: " + aSystemParameter.key.ToString() + "; " +
                                "  Value: " + aSystemParameter.value.ToString() + Environment.NewLine;
                        }
                    }
                }

                // Gather user parameters
                if (userParameters != null)
                {
                    foreach (WebReference.Param aUserParameter in userParameters)
                    {
                        if (aUserParameter != null)
                        {
                            userParametersString =
                                userParametersString +
                                "  Key: " + aUserParameter.key.ToString() + "; " +
                                "  Value: " + aUserParameter.value.ToString() + Environment.NewLine;
                        }
                    }
                }

                // Gather initial IDs
                if (initalIds != null)
                {
                    foreach (string aInitialId in initalIds)
                    {
                        if (aInitialId != null)
                        {
                            initialIdsString =
                                initialIdsString + "  " +
                                aInitialId + Environment.NewLine;
                        }
                    }
                }

                // Gather originator texts
                if (originatorTexts != null)
                {
                    foreach (string aOriginatorText in originatorTexts)
                    {
                        if (aOriginatorText != null)
                        {
                            originatorTextsString =
                                originatorTextsString + "  " +
                                aOriginatorText + Environment.NewLine;
                        }
                    }
                }

                // Combine results
                string textToPrint =
                    resultString + Environment.NewLine + Environment.NewLine +
                    "System parameters: " + Environment.NewLine +
                    systemParametersString + Environment.NewLine +
                    "User parameters: " + Environment.NewLine +
                    userParametersString + Environment.NewLine +
                    "Initial IDs: " + Environment.NewLine +
                    initialIdsString + Environment.NewLine +
                    "Originator texts: " + Environment.NewLine +
                    originatorTextsString;

                // Display results in a form
                frmPrintOut printOutForm = new frmPrintOut(textToPrint);
                printOutForm.ShowDialog();
            }
            else
            {
                MessageBox.Show("An error occured");
            }
        }

        /// <summary>
        /// Sends a test SMS to the web service and displays the result
        /// </summary>
        private void sendSMS()
        {
            // Create a variable that will receive the send response of the message
            WebReference.sendMsgResponse response;
            
            // Send a SMS-message
            response = webservice.sendSMS(
                txtUserName.Text.ToString(),
                txtPassword.Text.ToString());

            // Read and display the send response
            if (response != null)
            {
                string no = "";
                string status = "";
                string resultCode = "";
                string resultDescription = "";
                string createdTime = "";

                no = response.result.msgNo.ToString();
                status = response.result.msgStatus.ToString();
                resultCode = response.result.resultCode.ToString();
                if (response.result.resultDescription != null)
                { resultDescription = response.result.resultDescription.ToString(); }
                if (response.result.createTime != null)
                { createdTime = response.result.createTime.ToString();}

                // Combine results
                string textToPrint =
                    "Number: " + no + Environment.NewLine + 
                    "Status: " + status + Environment.NewLine + 
                    "Result code: " + resultCode + Environment.NewLine + 
                    "Result description: " + resultDescription + Environment.NewLine +
                    "Created time: " + createdTime;

                // Display result in a form
                frmPrintOut printOutForm = new frmPrintOut(textToPrint);
                printOutForm.ShowDialog();
            }
            else
            {
                MessageBox.Show("An error occured");
            }
        }

        /// <summary>
        /// Sends a test MMS to the web service and displays the result
        /// </summary>
        private void sendMMS()
        {
            // Create a variable that will receive the send response of the message
            WebReference.sendMsgResponse response;

            // Send a MMS-message
            response = webservice.sendMMS(
                txtUserName.Text.ToString(),
                txtPassword.Text.ToString());

            // Read and display the send response
            if (response != null)
            {
                string no = "";
                string status = "";
                string resultCode = "";
                string resultDescription = "";
                string createdTime = "";

                no = response.result.msgNo.ToString();
                status = response.result.msgStatus.ToString();
                resultCode = response.result.resultCode.ToString();
                if (response.result.resultDescription != null)
                { resultDescription = response.result.resultDescription.ToString(); }
                if (response.result.createTime != null)
                { createdTime = response.result.createTime.ToString(); }

                // Combine results
                string textToPrint =
                    "Number: " + no + Environment.NewLine +
                    "Status: " + status + Environment.NewLine + 
                    "Result code: " + resultCode + Environment.NewLine + 
                    "Result description: " + resultDescription + Environment.NewLine +
                    "Created time: " + createdTime;

                // Display result in a form
                frmPrintOut printOutForm = new frmPrintOut(textToPrint);
                printOutForm.ShowDialog();
            }
            else
            {
                MessageBox.Show("An error occured");
            }
        }

        /// <summary>
        /// Gets and displays the send result of a message
        /// </summary>
        private void getSendResult()
        {
            // Create a variable that will receive the send result response
            WebReference.getSendResultResponse response;
         
            // Get the send result of a message
            response = webservice.getSendResult(
                txtUserName.Text.ToString(),
                txtPassword.Text.ToString());

            // Read and display the send result response
            if (response != null)
            {
                string resultCode = "";
                string resultDescription = "";
                string sendRequestTime = "";
                string msgStatus = "";
                string recipientCount = "";
                string sentOkCount = "";
                string deliveredOkCount = "";
                string readOkCount = "";
                WebReference.RecipientResult[] recipients;

                resultCode = response.result.resultCode.ToString();
                if (response.result.resultDescription != null)
                { resultDescription = response.result.resultDescription.ToString(); }
                if (response.result.sendRequestTime != null)
                { sendRequestTime = response.result.sendRequestTime.ToString(); }
                msgStatus = response.result.msgStatus.ToString();
                recipientCount = response.result.recipientCount.ToString();
                sentOkCount = response.result.sentOkCount.ToString();
                deliveredOkCount = response.result.deliveredOkCount.ToString();
                readOkCount = response.result.readOkCount.ToString();
                recipients = response.result.recipientResults;

                string resultString = "";

                // Gather results
                resultString =
                    "  Result code: " + resultCode + Environment.NewLine +
                    "  Result description: " + resultDescription + Environment.NewLine +
                    "  Send request time: " + sendRequestTime + Environment.NewLine +
                    "  Message status: " + msgStatus + Environment.NewLine +
                    "  Recipient count: " + recipientCount + Environment.NewLine +
                    "  Sent OK count: " + sentOkCount + Environment.NewLine +
                    "  Delivered OK count: " + deliveredOkCount + Environment.NewLine +
                    "  Read OK count: " + readOkCount;

                string recipientsString = "";

                string recipientName = "";
                string recipientId = "";
                string mobileNumber = "";
                string operatorResultCode = "";
                string operatorResultDescription = "";
                string sentOk = "";
                string sentTime = "";
                string deliveredOk = "";
                string deliveredTime = "";
                string readOk = "";
                string readTime = "";

                // Gather the send result of each recipient
                foreach (WebReference.RecipientResult aRecipient in recipients)
                {
                    if (aRecipient != null)
                    {
                        recipientId = aRecipient.recipient.recipientId.ToString();
                        if (aRecipient.recipient.recipientName != null)
                        { recipientName = aRecipient.recipient.recipientName.ToString(); }
                        else { recipientName = ""; }
                        if (aRecipient.recipient.mobileNumber != null)
                        { mobileNumber = aRecipient.recipient.mobileNumber.ToString(); }
                        else { mobileNumber = ""; }
                        if (aRecipient.operatorResultCode != null)
                        { operatorResultCode = aRecipient.operatorResultCode.ToString(); }
                        else { operatorResultCode = ""; }
                        if (aRecipient.operatorResultDescription != null)
                        { operatorResultDescription = aRecipient.operatorResultDescription.ToString(); }
                        else { operatorResultDescription = ""; }
                        sentOk = aRecipient.sentOk.ToString();
                        if (aRecipient.sentTime != null)
                        { sentTime = aRecipient.sentTime.ToString(); }
                        else { sentTime = ""; }
                        deliveredOk = aRecipient.deliveredOk.ToString();
                        if (aRecipient.deliveredTime != null)
                        { deliveredTime = aRecipient.deliveredTime.ToString(); }
                        else { deliveredTime = ""; }
                        readOk = aRecipient.readOk.ToString();
                        if (aRecipient.readTime != null)
                        { readTime = aRecipient.readTime.ToString(); }
                        else { readTime = ""; }

                        recipientsString = recipientsString +
                            "  Name: " + recipientName + Environment.NewLine +
                            "  ID: " + recipientId + Environment.NewLine +
                            "  Mobile number: " + mobileNumber + Environment.NewLine +
                            "  Operator result code: " + operatorResultCode + Environment.NewLine +
                            "  Operator result description: " + operatorResultDescription + Environment.NewLine +
                            "  Sent OK: " + sentOk + Environment.NewLine +
                            "  Sent time: " + sentTime + Environment.NewLine +
                            "  Delivered OK: " + deliveredOk + Environment.NewLine +
                            "  Delivered time: " + deliveredTime + Environment.NewLine +
                            "  Read OK: " + readOk + Environment.NewLine +
                            "  Read time: " + readTime + Environment.NewLine +
                            Environment.NewLine;
                    }
                }

                // Combine results
                string textToPrint =
                    "Results: " + Environment.NewLine +
                    resultString + Environment.NewLine + Environment.NewLine +
                    "-------------------" + Environment.NewLine + Environment.NewLine +
                    "Recipient Results:" + Environment.NewLine +
                    recipientsString;

                // Display result in a form
                frmPrintOut printOutForm = new frmPrintOut(textToPrint);
                printOutForm.ShowDialog();
            }
            else
            {
                MessageBox.Show("An error occured");
            }
        }

        /// <summary>
        /// Gets and displays the send result of several messages
        /// </summary>
        private void getSendResults()
        {
            // Create a variable that will receive the delivery reports response
            WebReference.getSendResultsResponse response;

            // Get the send result of a set of messages
            response = webservice.getSendResults(
                txtUserName.Text.ToString(),
                txtPassword.Text.ToString());

            // Read and display the delivery reports response
            if (response != null)
            {
                string resultCode = "";
                string resultDescription = "";
                WebReference.MsgSendResultInfo[] msgSendResultInfos;

                resultCode = response.result.resultCode.ToString();
                if (response.result.resultDescription != null)
                { resultDescription = response.result.resultDescription.ToString(); }
                msgSendResultInfos = response.result.msgSendResultInfos;

                StringBuilder resultString = new StringBuilder();

                // Gather results
                resultString.Append(
                    "  Result code: " + resultCode + Environment.NewLine +
                    "  Result description: " + resultDescription);

                StringBuilder recipientsString = new StringBuilder();

                string msgNo = "";
                string sendRequestTime = "";
                string recipientCount = "";
                string sentOkCount = "";
                string smsCount = "";
                string deliveryOkCount = "";
                string readOkCount = "";

                // Gather the send result of each message
                foreach (WebReference.MsgSendResultInfo msgSendResultInfo in msgSendResultInfos)
                {
                    if (msgSendResultInfo != null)
                    {
                        msgNo = msgSendResultInfo.msgNo.ToString();
                        if (msgSendResultInfo.sendRequestTime != null)
                        { sendRequestTime = msgSendResultInfo.sendRequestTime.ToString(); }
                        else { sendRequestTime = ""; }
                        recipientCount = msgSendResultInfo.recipientCount.ToString();
                        sentOkCount = msgSendResultInfo.sentOkCount.ToString();
                        smsCount = msgSendResultInfo.smsCount.ToString();
                        deliveryOkCount = msgSendResultInfo.deliveredOkCount.ToString();
                        readOkCount = msgSendResultInfo.readOkCount.ToString();

                        recipientsString.Append(
                            "  Message number: " + msgNo + Environment.NewLine +
                            "  Send request time: " + sendRequestTime + Environment.NewLine +
                            "  Recipient count: " + recipientCount + Environment.NewLine +
                            "  Sent OK count: " + sentOkCount + Environment.NewLine +
                            "  SMS count: " + smsCount + Environment.NewLine +
                            "  Delivery OK count: " + deliveryOkCount + Environment.NewLine +
                            "  Read OK count: " + readOkCount + Environment.NewLine +
                            Environment.NewLine);
                    }
                }

                // Combine results
                string textToPrint =
                    "Results: " + Environment.NewLine +
                    resultString.ToString() + Environment.NewLine + Environment.NewLine +
                    "-------------------" + Environment.NewLine + Environment.NewLine +
                    "Message send results:" + Environment.NewLine +
                    recipientsString.ToString();

                // Display result in a form
                frmPrintOut printOutForm = new frmPrintOut(textToPrint);
                printOutForm.ShowDialog();
            }
            else
            {
                MessageBox.Show("An error occured");
            }
        }

        /// <summary>
        /// Gets and displays received messages
        /// </summary>
        private void getReceivedMessages()
        {
            // Create a variable that will receive get message response
            WebReference.getReceivedMessagesResponse response;
         
            // Get the received messages
            response = webservice.getReceivedMessages(
                txtUserName.Text.ToString(),
                txtPassword.Text.ToString());

            // Read and display the messages response
            if (response != null)
            {
                string resultCode = response.result.resultCode.ToString();
                string resultDescription = response.result.resultDescription;
                WebReference.MessageReceived[] messagesReceived = response.result.messagesReceived;

                string resultString = "";

                // Gather results
                resultString =
                    "  Result code: " + resultCode + Environment.NewLine +
                    "  Result description: " + resultDescription;

                string messagesReceivedString = "";

                string msgNo = "";
                string type = "";
                string initialID = "";
                string creatorName = "";
                string createdTime = "";
                string originator = "";
                string originatorText = "";
                string smsText = "";
                string mmsSubject = "";

                foreach (WebReference.MessageReceived messageReceived in messagesReceived)
                {
                    if (messageReceived != null)
                    {
                        msgNo = messageReceived.msgNo.ToString();
                        type = messageReceived.msgType.ToString();
                        if (messageReceived.initialId != null)
                        { initialID = messageReceived.initialId.ToString(); }
                        else { initialID = ""; }
                        if (messageReceived.creatorName != null)
                        { creatorName = messageReceived.creatorName.ToString(); }
                        else { creatorName = ""; }
                        if (messageReceived.createTime != null)
                        { createdTime = messageReceived.createTime.ToString(); }
                        else { createdTime = ""; }
                        if (messageReceived.originator != null)
                        { originator = messageReceived.originator.ToString(); }
                        else { originator = ""; }
                        if (messageReceived.originatorText != null)
                        { originatorText = messageReceived.originatorText.ToString(); }
                        else { originatorText = ""; }
                        if (messageReceived.smsText != null)
                        { smsText = messageReceived.smsText.ToString(); }
                        else { smsText = ""; }
                        if (messageReceived.subject != null)
                        { mmsSubject = messageReceived.subject.ToString(); }
                        else { mmsSubject = ""; }

                        messagesReceivedString = messagesReceivedString +
                            "  Message number: " + msgNo + Environment.NewLine +
                            "  Message type: " + type + Environment.NewLine +
                            "  Initial ID: " + initialID + Environment.NewLine +
                            "  Creator name: " + creatorName + Environment.NewLine +
                            "  Created time: " + createdTime + Environment.NewLine +
                            "  Originator: " + originator + Environment.NewLine +
                            "  Originator text: " + originatorText + Environment.NewLine +
                            "  SMS text: " + smsText + Environment.NewLine +
                            "  MMS subject: " + mmsSubject + Environment.NewLine + Environment.NewLine;
                    }
                }

                // Combine results
                string textToPrint =
                    "Results: " + Environment.NewLine +
                    resultString + Environment.NewLine + Environment.NewLine +
                    "-------------------" + Environment.NewLine + Environment.NewLine +
                    "Received messages:" + Environment.NewLine +
                    messagesReceivedString;

                // Display result in a form
                frmPrintOut printOutForm = new frmPrintOut(textToPrint);
                printOutForm.ShowDialog();
            }
            else
            {
                MessageBox.Show("An error occured");
            }
        }

        /// <summary>
        /// Gets the content of a received MMS and displays it
        /// </summary>
        private void getAReceivedMms()
        {
            // Create a variable that will receive the MMS content
            WebReference.getMsgContentResponse response;
         
            // Get a MMS's content
            response = webservice.getMmsContent(
                txtUserName.Text.ToString(),
                txtPassword.Text.ToString());

            // Read and display the parameter response
            if (response != null)
            {
                string resultCode = response.result.resultCode.ToString();
                string resultDescription = response.result.resultDescription;
                WebReference.MessageContent[] messageContent = response.result.contents;

                string resultString = "";

                // Gather results
                resultString =
                    "  Result code: " + resultCode + Environment.NewLine +
                    "  Result description: " + resultDescription;

                int slideNo;
                string contentType = "";
                string charset = "";
                string contentInfoString = "";
                string contentString = "";
                string textToPrint = "";
                Image contentImage = null;
                frmPrintOut printOutForm;

                // Gather and display content
                foreach (WebReference.MessageContent content in messageContent)
                {
                    if (content != null)
                    {
                        slideNo = (Int32)content.slideNo;
                        contentType = content.contentType.ToString();
                        //charset = content.contentCharset.ToString();

                        contentInfoString =
                            "  Content type: " + contentType + Environment.NewLine +
                            "  Slide number: " + slideNo + Environment.NewLine +
                            "  Charset: " + charset;

                        switch (contentType)
                        {
                            case "text/plain":
                                contentString = "  " +
                                    _utilities.getStringFromByteArray(content.contentBytes);

                                textToPrint =
                                    "Results: " + Environment.NewLine +
                                    resultString + Environment.NewLine + Environment.NewLine +
                                    "Page info: " + Environment.NewLine +
                                    contentInfoString + Environment.NewLine + Environment.NewLine +
                                    "Text content: " + Environment.NewLine +
                                    contentString;

                                // Display result in a form
                                printOutForm = new frmPrintOut(textToPrint);
                                printOutForm.ShowDialog();
                                break;

                            case "image/jpeg":
                            case "image/gif":
                                contentImage = _utilities.getImageFromByteArray(content.contentBytes);

                                textToPrint =
                                    "Results: " + Environment.NewLine +
                                    resultString + Environment.NewLine + Environment.NewLine +
                                    "Page info: " + Environment.NewLine +
                                    contentInfoString;

                                // Display result in a form
                                frmPrintOutContent printOutContentForm = new frmPrintOutContent(contentImage, textToPrint);
                                printOutContentForm.ShowDialog();
                                break;

                            default:
                                //
                                break;
                        }
                    }
                    else
                    {
                        textToPrint =
                            "Results: " + Environment.NewLine +
                            resultString;
                        
                        // Display result in a form
                        printOutForm = new frmPrintOut(textToPrint);
                        printOutForm.ShowDialog();
                    }
                }
            }
            else
            {
                MessageBox.Show("An error occured");
            }
        }
    }
}